@@ -9,7 +9,7 @@ use URI::Escape;
 use WebService::Simple::Response;
 use UNIVERSAL::require;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 __PACKAGE__->config(
     base_url        => '',
@@ -154,19 +154,25 @@ sub get {
     my $response;
     $response = $self->__cache_get( [ $uri, @headers ] );
     if ($response) {
-        return $response;
+        if ($response->isa('WebService::Simple::Response')) { # backward compatibility
+            return $response;
+        } else {
+            return WebService::Simple::Response->new_from_response(
+                response => $response,
+                parser => $self->response_parser
+            );
+        }
     }
 
     $response = $self->SUPER::get( $uri, @headers );
     if ( !$response->is_success ) {
         Carp::croak("request to $uri failed");
     }
-
+    $self->__cache_set( [ $uri, @headers ], $response );
     $response = WebService::Simple::Response->new_from_response(
         response => $response,
         parser   => $self->response_parser
     );
-    $self->__cache_set( [ $uri, @headers ], $response );
     return $response;
 }
 
@@ -174,15 +180,16 @@ sub post {
     my $self = shift;
     my ( $url, %extra );
 
-    if ( ref $_[0] eq 'HASH' ) {
+    if ( ref $_[0] eq 'HASH' ) {    # post(\%arg [, @header ])
         $url   = "";
         %extra = %{ shift @_ };
     }
-    else {
+    elsif ( ref $_[1] eq 'HASH' ) { # post($url, \%arg [, @header ])
+        $url = shift @_;
+        %extra = %{ shift @_ };
+    }
+    elsif ( @_ % 2 ) {              # post($url [, @header ])
         $url = shift @_;
-        if ( ref $_[0] eq 'HASH' ) {
-            %extra = %{ shift @_ };
-        }
     }
 
     # XXX - do not include params
@@ -239,6 +246,25 @@ WebService::Simple is a simple class to interact with web services.
 It's basically an LWP::UserAgent that remembers recurring api URLs and
 parameters, plus sugar to parse the results.
 
+=head1 EXAMPLE
+
+Example script using Twitter Search API.
+
+    use WebService::Simple;
+    binmode STDOUT, ":utf8";
+
+    my $service = WebService::Simple->new(
+        base_url        => 'http://search.twitter.com/search.json',
+        param           => { locale => 'ja' },
+        response_parser => 'JSON'
+    );
+
+    my $res = $service->get( { q => 'perl' } );
+    my $json = $res->parse_response;
+    for my $tweet ( @{ $json->{results} } ) {
+        print "$tweet->{from_user}: $tweet->{text}\n";
+    }
+
 =head1 METHODS
 
 =over 4
