@@ -1,4 +1,4 @@
-# $Id: JSON.pm 10404 2008-04-25 02:38:23Z yusukebe $
+# $Id: JSON.pm 26994 2008-12-18 03:11:11Z drry $
 
 package WebService::Simple::Parser::JSON;
 use strict;
@@ -22,8 +22,7 @@ sub parse_response
     my $self = shift;
     my $content =$_[0]->content;
     # JSONP to pure JSON
-    $content =~ s/[a-zA-Z0-9_]+\((.+)\)/$1/;
-    $content =~ s/;$//;
+    $content =~ s/[a-zA-Z_\$][a-zA-Z0-9_\$]*\s*\((.+)\)\s*;?\s*$/$1/;
     $self->{json}->decode( $content );
 }
 
